﻿using System.Windows.Controls;
using Infragistics.Controls.Grids;
using Infragistics;
using Infragistics.Controls.Menus;
using System.Reflection;

namespace SilverlightApplication1
{
    public partial class MainPage : UserControl
    {
        #region Private Methods
       
        /// <summary>
        /// Gets the value of xamGrid's currently Active cell from the underlying ItemsSource 
        /// using reflection.
        /// </summary>
        /// <returns>
        /// Null if there's no Active cell in the grid. 
        /// Object value obtained from the ItemsSource otherwise.
        /// </returns>
        private object GetValueFromDataSource()
        {
            if (igGrid.ActiveCell == null || igGrid.ActiveCell.Row.RowType != RowType.DataRow)
                return null;

            MyDataObject data = igGrid.ActiveCell.Row.Data as MyDataObject;
            string propertyName = igGrid.ActiveCell.Column.Key;

            PropertyInfo propertyInfo = data.GetType().GetProperty(propertyName);
            
            return propertyInfo.GetValue(data, null);
        }

        /// <summary>
        /// Clears the "Log" listbox
        /// </summary>
        private void btnClearLog_Click(object sender, System.Windows.RoutedEventArgs e)
        {
            lbLog.Items.Clear();
        }

        /// <summary>
        /// Adds a message to the "Log" listbox
        /// </summary>
        private void LogMessage(string message)
        {
            lbLog.Items.Add(message);
        }

        #region XamMenu events

        private void XamMenu_ItemClicked(object sender, Infragistics.Controls.Menus.ItemClickedEventArgs e)
        {
            LogMessage("Event fired: Menu Clicked");
        }

        private void XamMenuItem_Click(object sender, System.EventArgs e)
        {
            object valueFromDataSource = GetValueFromDataSource();
            LogMessage("Value From Data Source: " + ((valueFromDataSource == null) ? "null" : valueFromDataSource.ToString()));
            LogMessage("Event fired: MenuItem Clicked: " + ((XamMenuItem)sender).Header.ToString());
        }
        
        #endregion // XamMenu events

        #region XamGrid event handlers

        private void igGrid_CellExitedEditMode(object sender, CellExitedEditingEventArgs e)
        {
            LogMessage("Event fired: Cell Exited Edit Mode");
        }

        private void igGrid_CellEditingValidationFailed(object sender, CellValidationErrorEventArgs e)
        {
            e.Handled = true;
            igGrid.ExitEditMode(true);
        }

        
        #endregion // XamGrid event handlers

        #endregion // Private methods

        #region ctor

        public MainPage()
        {
            InitializeComponent();
        }

        #endregion
    }
}
